Standard functions (dsptoolbox.*)
===================================================================

.. automodule:: dsptoolbox.standard_functions
   :members:
   :undoc-members:
   :show-inheritance:
